@@ -1,6 +1,6 @@
 use crate::enums::{TypeHolder, Types};
 use crate::types_structs::{Enum, ItemInfo, Struct, Trait, TYPE_CASE};
-use crate::TypeCases;
+use crate::{TypeCases, Language};
 use derive_new::new;
 use std::collections::{HashMap, VecDeque};
 use std::fs::{DirEntry, File};
@@ -291,10 +291,13 @@ impl ItemsHolder {
         self.enums_list.push(data)
     }
 
-    fn generate_interface(mut self, out_file: &PathBuf) {
+    fn generate_interface(mut self,language:Language, out_file: &PathBuf) {
         //println!("final {:?}", self.final_list);
         let mut file = File::create(out_file).expect("Unable to write to disk");
-        file.write(b"//Automatically generated by rust_interface_generator\nuse crate::*;\nuse jni_sys::*;\n").unwrap();
+        file.write(b"//Automatically generated by rust_interface_generator\nuse crate::*;\n").unwrap();
+        if matches!(language,Language::Java) {
+            file.write_all(b"use jni_sys::*;\n").unwrap();
+        }
         //first add enums since enums "can't" depend on other data structures
         self.sort_items();
         for mut enums in self.enums_list {
@@ -302,7 +305,7 @@ impl ItemsHolder {
                 .expect("Unable to write to disk");
         }
 
-            /*assert_eq!(
+        /*assert_eq!(
             self.final_list,
             vec![
                 Rc::new("OTH".into()),
@@ -359,7 +362,7 @@ impl FileGenerator {
         }
     }
 
-    pub fn build(&self) {
+    pub fn build(&self,language:Language) {
         //let start = Instant::now();
         //the closure to be applied to each file
         let mut file_data: HashMap<Rc<String>, TypeHolder> = HashMap::new();
@@ -492,7 +495,7 @@ impl FileGenerator {
                 TypeHolder::Enum(val) => holder.add_enum(val),
             }
         }
-        holder.generate_interface(&self.interface_file_path);
+        holder.generate_interface(language,&self.interface_file_path);
         //println!("total time {:?}", start.elapsed());
     }
 
